NetworkApiService class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshConfig() → void
Rebuilds the underlying Dio client using the latest PagyConfig.
request({required String endPoint, required String method, Map<String, dynamic>? queryParameters, dynamic body, String? token, bool isAuthorize = false, Map<String, String>? extraHeaders, CancelToken? cancelToken}) → Future<Response>
Unified API request handler (supports GET & POST)
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → NetworkApiService
final