refreshConfig method
void
refreshConfig()
Rebuilds the underlying Dio client using the latest PagyConfig.
Implementation
void refreshConfig() {
_dio = _buildDio();
}
Rebuilds the underlying Dio client using the latest PagyConfig.
void refreshConfig() {
_dio = _buildDio();
}