PagyParams<T> class
Constructors
-
PagyParams({required String endPoint, required PagyApiRequestType requestType, num? page, num? limit, Map<
String, dynamic> ? queryParameter, Map<String, dynamic> ? additionalQueryParams, dynamic payloadData, String? token, Map<String, String> ? headers, CancelToken? cancelToken, PaginationPayloadMode? paginationMode, required T fromMap(Map<String, dynamic> )})
Properties
-
additionalQueryParams
→ Map<
String, dynamic> ? -
final
- cancelToken → CancelToken?
-
final
- endPoint → String
-
final
-
fromMap
→ T Function(Map<
String, dynamic> ) -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
final
- limit → num?
-
final
- page → num?
-
final
- paginationMode → PaginationPayloadMode?
-
final
- payloadData → dynamic
-
final
-
queryParameter
→ Map<
String, dynamic> ? -
final
- requestType → PagyApiRequestType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited